# 🚀 programmering.no | 🤓 matematikk.as
# 1T - Eksamen - 2022 Høst (Udir)
# Oppgave 3 b) Rasjonal funksjon til Lars - Kun if-blokker 

def f(x):
	return (1 - 2 * x) / (x - 2)

x = 8

while x >= -8:

    if x != 2: print(x, f(x))
    if x == 2: print(x, "Ikke definert: x = 2 deler på 0")

    x = x - 1
