# 🚀 programmering.no | 🤓 matematikk.as
# - Lag et json-obj (liste med dictionaries)

# Variabler
json_obj = [
    {"fornavn": "Supermann", "alder": 25, "emoji": "💫"},
    {"fornavn": "Lynvingen", "alder": 42, "emoji": "🦇"},
    {"fornavn": "Wolverine", "alder": 31, "emoji": "🐺"},
    {"fornavn": "Spiderman", "alder": 23, "emoji": "🕸"}
]

# Iterer gjennom json_obj og print obj
for obj in json_obj:
    print(obj)
