# 🚀 programmering.no | 🤓 matematikk.as
# - Regn ut summen av to tall

# Verdier
a = input("Tall 1: ")
b = input("Tall 2: ")

# Regn ut summen
c = float(a) + float(b) # Type cast inp-str -> float

# Print
print(f"Summen er: {a} + {b} = {c}")
