# 🚀 programmering.no | 🤓 matematikk.as
# - Remove (slett) element fra sett

# Variabler
sett = {"bil", "tog", "sykkel"}

# Print originalt sett
print(f"Originalt sett: {sett}")

# Remove et element fra settet
sett.remove("bil")

# Print oppdatert sett
print(f"Oppdatert sett: {sett}")
