# 🚀 programmering.no | 🤓 matematikk.as
# - Transponer matrise med numpy

import numpy

# Verdier
matrise = [[1, 2, 3], [4, 5, 6]]

# Transponer matrisen
matrise_transpose = numpy.transpose(matrise)

# Print
print("")
print("Matrise:")
print(matrise)

print("")
print("Transponert matrise:")
print(matrise_transpose)
