# 🚀 programmering.no | 🤓 matematikk.as
# - Eksempel på complex (komplekse tall)

# Variabler
komplekst_tall_1 = 2 + 4j
komplekst_tall_2 = 3 + 5j

# Finn summen av to komplekste tall
komplekst_tall_sum = komplekst_tall_1 + komplekst_tall_2

# Print
print(komplekst_tall_sum)
