# 🚀 programmering.no | 🤓 matematikk.as
# - Finn antall elementer i en liste med len()

# Verdier
liste = ["Merkus", "Venus", "Jorden", "Mars"]

# Print
print(f"Liste: {liste}")

# Antall el i listen ("lengden" til listen)
el_ant = len(liste)

# Print
print(f"Antall el i listen: {el_ant}")
