# 🚀 programmering.no | 🤓 matematikk.as
# - Ugyldige variabelnavn

# Variabler
1variabel    = "Funker koden?"
en variabel  = "Hva med dette?"
spesialtegn$ = "Hvorfor funker ikke koden?"

# Print
print(spesialtegn$)
