# 🚀 programmering.no | 🤓 matematikk.as
# - Endre value med key

# Variabler
obj = {
    "navn":  "Supermann",
    "alder": 23
}

# Print obj
print(obj)

# Legger til et nytt felt fordi key ikke eksisterer
obj["emoji"] = "💫"

# Print oppdatert obj
print(obj)
