# 🚀 programmering.no | 🤓 matematikk.as
# - Endre value med key

# Variabler
obj = {
    "navn":  "Supermann",
    "alder": 23
}

# Endre value med key
obj["navn"] = "Batman"

# Print oppdatert obj
print(obj)

# Print oppdatert navn
print(obj["navn"])
