# 🚀 programmering.no | 🤓 matematikk.as
# - Reverserer rekkefølgen til elementene i en liste
# - Hastighet reverse(): Ca. 33 ms per loop for liste m/ 100 000 000 el

# Variabler
liste = [1, 2, 3, 4]

# Print
print(f"Original liste  : {liste}")

# Reverse
liste.reverse()

# Print
print(f"Reversert liste : {liste}")
